#include <Wire.h>
#include <Adafruit_NeoPixel.h>

#define I2C_ADDRESS 0x08  // Dirección I2C de este esclavo
#define NEOPIXEL_PIN 12   // Pin del NeoPixel integrado
#define ENABLE_PIN 11     // Pin para habilitar la alimentación del NeoPixel
#define NUM_PIXELS 1      // Número de NeoPixels

Adafruit_NeoPixel pixel(NUM_PIXELS, NEOPIXEL_PIN, NEO_GRB + NEO_KHZ800);

void setup() {
  Wire.begin(I2C_ADDRESS);      // Iniciar I2C como esclavo
  Wire.onReceive(receiveEvent); // Evento para recibir datos del maestro

  pinMode(ENABLE_PIN, OUTPUT);
  digitalWrite(ENABLE_PIN, HIGH);  // Activar alimentación al NeoPixel

  pixel.begin();                // Iniciar NeoPixel
  pixel.show();                 // Apagar NeoPixel inicialmente

  Serial1.begin(115200);        // Comunicación serial con Slave 2
}

void loop() {
  // No se requiere lógica adicional aquí
}

void receiveEvent(int howMany) {
  if (Wire.available()) {
    int colorCode = Wire.read();  // Leer datos enviados por el maestro

    // Ajustar color en NeoPixel basado en el código recibido
    switch (colorCode) {
      case 1: pixel.setPixelColor(0, pixel.Color(255, 0, 0)); break; // Rojo
      case 2: pixel.setPixelColor(0, pixel.Color(0, 255, 0)); break; // Verde
      case 3: pixel.setPixelColor(0, pixel.Color(0, 0, 255)); break; // Azul
      default: pixel.setPixelColor(0, 0); break; // Apagar
    }
    pixel.show();  // Actualizar el color del NeoPixel

    // Enviar texto descriptivo a Slave 2 a través de Serial1
    String mensaje;
    switch (colorCode) {
      case 1: mensaje = "RED"; break;
      case 2: mensaje = "GREEN"; break;
      case 3: mensaje = "BLUE"; break;
      default: mensaje = "OFF"; break;
    }

    Serial1.println(mensaje);  // Enviar mensaje al Slave 2
  }
}
