#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128  // Ancho del OLED
#define SCREEN_HEIGHT 64  // Alto del OLED
#define OLED_RESET -1     // Pin de reset (no se usa con XIAO)
#define SCREEN_ADDRESS 0x3C  // Dirección I2C de la pantalla OLED
#define I2C_ADDRESS 0x09  // Dirección de esta Slave 2

Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

String textoRecibido = "";

void setup() {
  Wire.begin(I2C_ADDRESS);  // Iniciar I2C como esclavo
  Wire.onReceive(receiveEvent);  // Evento para recibir texto desde la Slave 1

  if (!display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS)) {
    Serial.println(F("Error al iniciar SSD1306"));
    for (;;);
  }

  display.clearDisplay();
  display.setTextSize(1);
  display.setTextColor(SSD1306_WHITE);
  display.setCursor(0, 0);
  display.println("Esperando datos...");
  display.display();

  Serial.begin(115200);
}

void loop() {
  if (textoRecibido != "") {
    mostrarTextoEnLCD(textoRecibido);
    textoRecibido = "";  // Limpiar después de mostrar
  }
}

void receiveEvent(int howMany) {
  char buffer[32];  // Buffer para recibir el texto
  int index = 0;

  while (Wire.available() && index < sizeof(buffer) - 1) {
    buffer[index++] = Wire.read();
  }
  buffer[index] = '\0';  // Terminar cadena
  textoRecibido = String(buffer);
  Serial.println("Texto recibido: " + textoRecibido);
}

void mostrarTextoEnLCD(String texto) {
  display.clearDisplay();
  display.setCursor(0, 0);
  display.println("Color:");
  display.setCursor(0, 16);
  display.println(texto);
  display.display();
}
