#include <Wire.h>
#include <BH1750.h>
#include <Adafruit_NeoPixel.h>

#define I2C_ADDRESS 0x08  // Dirección de esta XIAO RP2040
#define NEOPIXEL_PIN 12   // Pin del NeoPixel integrado en la XIAO RP2040
#define ENABLE_PIN 11     // Pin para habilitar el NeoPixel
#define NUM_PIXELS 1      // Solo 1 NeoPixel

BH1750 lightMeter;
Adafruit_NeoPixel pixel(NUM_PIXELS, NEOPIXEL_PIN, NEO_GRB + NEO_KHZ800);

int numMediciones = 0;

void setup() {
  pinMode(ENABLE_PIN, OUTPUT);
  digitalWrite(ENABLE_PIN, HIGH); // Activar el pin 11 para encender el NeoPixel

  Wire.begin(I2C_ADDRESS);        // Iniciar I2C como esclavo
  Wire.onReceive(receiveEvent);   // Evento para recibir datos del maestro

  if (!lightMeter.begin()) {
    Serial.println("Error al iniciar BH1750");
    while (1);
  }

  pixel.begin();  // Inicializar NeoPixel
  pixel.show();   // Asegurarse de que esté apagado al inicio

  Serial.begin(115200); // Monitor Serial para depuración
}

void loop() {
  if (numMediciones > 0) {
    parpadearNeoPixel(numMediciones);  // Parpadea el NeoPixel según el número recibido
    
    for (int i = 0; i < numMediciones; i++) {
      float lightLevel = lightMeter.readLightLevel();  // Leer nivel de luz
      Serial.println("Luz: " + String(lightLevel) + " lx");
      delay(1000);  // Tomar una medición cada segundo
    }
    numMediciones = 0;  // Resetear número de mediciones
  }
}

void receiveEvent(int howMany) {
  if (Wire.available()) {
    numMediciones = Wire.read();  // Leer el número enviado por el maestro
    Serial.println("Numero de mediciones: " + String(numMediciones)); // Debug
  }
}

void parpadearNeoPixel(int veces) {
  for (int i = 0; i < veces; i++) {
    pixel.setPixelColor(0, pixel.Color(255, 0, 0));  // Encender en rojo
    pixel.show();
    delay(500);  // Mantener encendido por 500ms

    pixel.setPixelColor(0, 0);  // Apagar
    pixel.show();
    delay(500);  // Mantener apagado por 500ms
  }
}
