#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

// Definición de ancho y alto de la pantalla
#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 64

#define OLED_RESET    -1       // Reset pin # (or -1 if sharing Arduino reset pin)
#define SCREEN_ADDRESS 0x3C    // Dirección I2C estándar para OLED
#define I2C_ADDRESS 0x09       // Dirección de esta XIAO RP2040

Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

float datosLuz[100];  // Arreglo para almacenar las mediciones
int numMediciones = 0;

void setup() {
  Wire.begin(I2C_ADDRESS);    // Iniciar I2C como esclavo
  Wire.onReceive(receiveEvent); // Evento para recibir datos

  if (!display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS)) { // Inicializar OLED
    Serial.println(F("SSD1306 no encontrado"));
    for (;;); // Detener si no se encuentra
  }

  display.clearDisplay();
  display.setTextSize(1);
  display.setTextColor(SSD1306_WHITE);
  display.setCursor(0, 0);
  display.println("Esperando datos...");
  display.display();

  Serial.begin(115200);  // Monitor Serial para depuración
}

void loop() {
  if (numMediciones > 0) {
    mostrarDatosEnLCD();
    numMediciones = 0; // Reiniciar para la próxima recepción
  } else {
    displayEsperando();
  }
}

void receiveEvent(int howMany) {
  int index = 0;
  while (Wire.available() && index < 100) {
    Wire.readBytes((char*)&datosLuz[index], sizeof(float)); // Leer cada medición
    index++;
  }
  numMediciones = index;  // Actualizar la cantidad de mediciones recibidas
  Serial.println("Datos recibidos: " + String(numMediciones)); // Debug
}

void mostrarDatosEnLCD() {
  display.clearDisplay();
  display.setCursor(0, 0);
  display.println("Datos de Luz (lx):");

  for (int i = 0; i < numMediciones; i++) {
    display.setCursor(0, 10 + i * 8); // Ajustar la posición de cada línea
    display.println(String(i + 1) + ": " + String(datosLuz[i], 2));
    if ((10 + i * 8) >= SCREEN_HEIGHT - 8) { // Si supera el tamaño de pantalla
      break; // Mostrar solo lo que cabe
    }
  }
  display.display(); // Mostrar en pantalla
}

void displayEsperando() {
  display.clearDisplay();
  display.setCursor(0, 0);
  display.println("Esperando datos...");
  display.display();
}
